# controllogger

A simple and easy to use logger for python.

## Getting Started

Download links:

* pip install controllogger
* ssh clone URL: git@github.com:JuliusKoenig/controllogger.git
* https clone URL: https://github.com/JuliusKoenig/controllogger.git


